
--------------------------------------

spartan: potent visualization
=======================================

[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)


Spartan is a Python visualization library based on matplotlib that provides a style, palettes and plot types that enhance communication. The philosophy is based around Tufte's minimalist ideas as well as storytelling strategies and good use of color. 

All you need to do is import the library and you will get clean, potent plots using the usual matplotlib commands.

<!---
Spartan provides:
* a basic clean, Tufte like style
* user customizations and context styles (e.g., screen, publication, talk, poster)
* palettes designed to tell a range of stories
* sparklines
* range frames
* scatter plots with rugs and KDEs
--->
